.. :GeometryConcept:

GeometryConcept
===============

.. currentmodule:: Geometry.GeometryConcept


.. autosummary::
   :nosignatures:

	GeometryConcept.GeometryConcept
    GeometryConcept.GeometryConcept.__init__
    GeometryConcept.GeometryConcept.plot

    GeometryConcept.GeometryObject
    GeometryConcept.GeometryObject.__init__
    


GeometryConcept Object and Methods
----------------------------------


.. automodule:: GeometryConcept

.. _GeometryConcept:

.. autoclass:: GeometryConcept
    :members:

    .. automethod:: __init__


GeometryObject Object and Methods
---------------------------------


.. _GeometryObject:

.. autoclass:: GeometryObject
    :members:

    .. automethod:: __init__

